ngff_zarr.methods._itkwasm - ngff-zarr
Description: Module Contents: Functions:,,_itkwasm_blur_and_downsample, Blur and then downsample a given image chunk,,_itkwasm_chunk_bin_shrink, Compute the local mean and downsample on a given image chunk,,_do...

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.methods._itkwasm`

## Module Contents

### Functions

`_itkwasm_blur_and_downsample` | Blur and then downsample a given image chunk
`_itkwasm_chunk_bin_shrink` | Compute the local mean and downsample on a given image chunk
`_downsample_itkwasm_bin_shrink` |
`_downsample_itkwasm` |

### Data

`_image_dims` |

### API

ngff_zarr.methods._itkwasm._image_dims: Tuple[str, str, str, str]

  (‘x’, ‘y’, ‘z’, ‘t’)

ngff_zarr.methods._itkwasm._itkwasm_blur_and_downsample(image_data, shrink_factors, kernel_radius, smoothing)

  Blur and then downsample a given image chunk

ngff_zarr.methods._itkwasm._itkwasm_chunk_bin_shrink(image_data, shrink_factors)

  Compute the local mean and downsample on a given image chunk

ngff_zarr.methods._itkwasm._downsample_itkwasm_bin_shrink(ngff_image: ngff_zarr.ngff_image.NgffImage, default_chunks, out_chunks, scale_factors)

ngff_zarr.methods._itkwasm._downsample_itkwasm(ngff_image: ngff_zarr.ngff_image.NgffImage, default_chunks, out_chunks, scale_factors, smoothing)